@@ -69,6 +69,8 @@ fill_priv(Animation_WallpaperPrivate *priv)
                 priv->scene_func = (gpointer)&init_scene_External;
             if (!strcmp(priv->theme, "Conky"))
                 priv->scene_func = (gpointer)&init_scene_Conky;
+            if (!strcmp(priv->theme, "Flash"))
+                priv->scene_func = (gpointer)&init_scene_Flash;
             priv->hash_theme = store->data;
             break;
         }
@@ -243,3 +245,33 @@ save_config(Animation_WallpaperPrivate *priv) {
         }
     }
 }
+/*******************************************************************************/
+gint
+get_count_themes_from_config(gchar *theme_name){
+    GConfClient *gconf_client;
+    gint i, count;
+    gchar *str, *value;
+
+    gconf_client = gconf_client_get_default();
+    if (!gconf_client) {
+        fprintf(stderr, _("Failed to initialize GConf. Quitting.\n"));
+        return FALSE;
+    }
+    /* get count such themes */
+    count = 0;
+    for (i=1; i<=9; i++){
+        str = g_strdup_printf("%s%i", GCONF_KEY_THEME, i);
+        value = gconf_client_get_string(gconf_client, str, NULL);
+        if (str){ 
+            g_free(str);
+            str = NULL;
+        }    
+        if (value && !strcmp(value, theme_name)){
+            count++;
+        }
+
+    }
+    //fprintf(stderr, "get count_theme from config = %d\n", count);
+    return count;
+}
+
