@@ -7,8 +7,8 @@
  *       for the code
  * 
  * This software is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public License
- * as published by the Free Software Foundation; either version 2.1 of
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2 of
  * the License, or (at your option) any later version.
  * 
  * This software is distributed in the hope that it will be useful, but
@@ -67,11 +67,16 @@ lw_applet_realize (GtkWidget *widget)
 	    case 3: child_argv[1] = "4";
 		break;
     }
-
-    desktop_plugin->priv->pid = fork();
-    if (desktop_plugin->priv->pid == 0){
-    	execvp("/usr/bin/livewp", child_argv);
-    	fprintf(stderr,"Problem with new process");
+    desktop_plugin->priv->one_in_all_view = get_one_in_all_views_from_config();
+    /* Check one theme in all view mode */
+    if (!desktop_plugin->priv->one_in_all_view || 
+        (desktop_plugin->priv->one_in_all_view && id == 0)){
+	    /* Start a new process */
+	    desktop_plugin->priv->pid = fork();
+	    if (desktop_plugin->priv->pid == 0){
+		execvp("/usr/bin/livewp", child_argv);
+		fprintf(stderr,"Problem with new process");
+	    }
     }
 
     desktop_plugin_visible_notify((GObject *)widget, NULL, desktop_plugin);
@@ -145,18 +150,20 @@ desktop_plugin_visible_notify (GObject    *object,
     gboolean visible;
     Animation_WallpaperPrivate *priv = desktop_plugin->priv;
     g_object_get (object, "is-on-current-desktop", &visible, NULL);
-    /* fprintf (stderr, "is-on-current-desktop changed. visible: %u", visible); */
+    fprintf (stderr, "LWP is-on-current-desktop changed. visible: %u", visible); 
     if (priv){
-	/*    
-        if (visible){
+             if (priv->one_in_all_view){
+		     if (visible)
 			send_dbus_signal (priv, LIVEWP_SIGNAL_INTERFACE, 
-				  LIVEWP_SIGNAL_PATH, LIVEWP_PLAY_LIVEBG_ON_VIEW);
-        }else{ 
-			send_dbus_signal (priv, LIVEWP_SIGNAL_INTERFACE, 
-				  LIVEWP_SIGNAL_PATH, LIVEWP_PAUSE_LIVEBG_ON_VIEW);
-        }
-        */    
-        
+					  LIVEWP_SIGNAL_PATH, LIVEWP_PLAY_LIVEBG_ON_VIEW1);
+		     else{
+			/* start any application on current view */
+			if ((priv->view + 1) == current_active_view())
+				send_dbus_signal (priv, LIVEWP_SIGNAL_INTERFACE, 
+					  LIVEWP_SIGNAL_PATH, LIVEWP_PAUSE_LIVEBG_ON_VIEW1);
+		     }
+		     return;
+             }
 	     switch (priv->view + 1){
 		case 1: if (visible)
 				send_dbus_signal (priv, LIVEWP_SIGNAL_INTERFACE, 
@@ -187,6 +194,7 @@ desktop_plugin_visible_notify (GObject    *object,
 					  LIVEWP_SIGNAL_PATH, LIVEWP_PAUSE_LIVEBG_ON_VIEW4);
 			break;
 	     }
+
      }
     
 }
@@ -231,6 +239,7 @@ animation_wallpaper_plugin_init (AWallpaperPlugin *desktop_plugin)
     priv->xapplet = 0;
     priv->yapplet = 0;
     priv->scene = NULL;
+    priv->pid = 0;
     priv->theme = g_strdup("Modern");
     //priv->theme = g_strdup("Accel");
     desktop_plugin->priv->main_widget = gtk_fixed_new();
@@ -272,7 +281,6 @@ fprintf(stderr,"lw_applet_finalize\n");
 	     destroy_scene(desktop_plugin);
      }
 */    
-     
      if (priv){
 	     switch (priv->view + 1){
 		case 1: send_dbus_signal (priv, LIVEWP_SIGNAL_INTERFACE, 
@@ -293,16 +301,20 @@ fprintf(stderr,"lw_applet_finalize\n");
          g_source_remove(priv->alive_timer);
 
      livewp_deinitialize_dbus(priv);
-     while (TRUE){
-         wpid = wait(&status);
-	 if (wpid == priv->pid)
-	     break;
+
+     if (priv->pid >0){
+	     while (TRUE){
+		 wpid = wait(&status);
+		 if (wpid == priv->pid)
+		     break;
+	     }
      }
 }
 
 static void
 desktop_widget_finalize (GObject *object)
 {
+fprintf(stderr,"desktop lw_applet_finalize\n");
       /* Call the base class's implementation: */
      G_OBJECT_CLASS (animation_wallpaper_plugin_parent_class)->finalize (object);
 }
