@@ -35,10 +35,10 @@ static gboolean short_timeout (AWallpaperPlugin *desktop_plugin);
 void run_long_timeout(AWallpaperPlugin *desktop_plugin);
 gboolean long_timeout (AWallpaperPlugin *desktop_plugin);
 void conky_visible(AWallpaperPlugin *desktop_plugin);
+void flash_visible(AWallpaperPlugin *desktop_plugin);
 
 void 
-set_live_bg (Display *display, Window xwindow, int mode)
-{
+set_live_bg (Display *display, Window xwindow, int mode){
    Atom atom;
    atom = XInternAtom (display, "_HILDON_LIVE_DESKTOP_BACKGROUND", False);
    fprintf (stderr, "XID: 0x%x\n", (unsigned)xwindow);
@@ -78,6 +78,11 @@ view_state_changed (Animation_WallpaperPrivate *priv)
            conky_visible(priv->desktop_plugin);
            return;
        }
+       /* For Flash */
+       if (!strcmp(priv->theme,"Flash")&& priv->running){
+           flash_visible(priv->desktop_plugin);
+           return;
+       }
 
        if (!priv->running){
             if (priv->hash_theme && g_hash_table_lookup(priv->hash_theme, "exec_path")){
@@ -104,6 +109,12 @@ view_state_changed (Animation_WallpaperPrivate *priv)
            conky_visible(priv->desktop_plugin);
            return;
         }
+        /* For Flash */
+        if (!strcmp(priv->theme,"Flash")){
+           flash_visible(priv->desktop_plugin);
+           return;
+        }
+
         if (priv->long_timer != 0 ){
             g_source_remove(priv->long_timer);
             priv->long_timer = 0;
@@ -293,14 +304,25 @@ void
 create_xwindow (Animation_WallpaperPrivate *priv){
     GtkWidget *main_widget = NULL;
     GtkWidget *label = NULL;
+
     /* Create Main GUI */
     main_widget = hildon_window_new ();
     priv->window = main_widget;
     gtk_window_set_title(GTK_WINDOW(main_widget), PACKAGE);
     gtk_window_fullscreen(GTK_WINDOW(main_widget));
-    label = gtk_label_new(_("Loading Livewallpaper scene ..."));
-    gtk_container_add (GTK_CONTAINER (main_widget), label);
+
+    /* Check parametr 'gtk_socket_id'. It use in flash player for example */
+    if (g_hash_table_lookup(priv->hash_theme, "gtk_socket_id")){
+        priv->video_socket = gtk_socket_new ();
+        gtk_container_add (GTK_CONTAINER (priv->window), priv->video_socket);
+    }else{
+        label = gtk_label_new(_("Loading Livewallpaper scene ..."));
+        gtk_container_add (GTK_CONTAINER (main_widget), label);
+    }
+
     gtk_widget_show_all(GTK_WIDGET(main_widget));
+
+    /* Set window to background mode */
     if (priv->one_in_all_view)
         set_live_bg(GDK_WINDOW_XDISPLAY (main_widget->window), GDK_WINDOW_XID (main_widget->window), -1);
     else
