@@ -227,32 +227,45 @@ init_scene_External(AWallpaperPlugin *desktop_plugin){
         *window_id = NULL,
         *window_name = NULL,
         *view = NULL,
+        *gtk_socket_id = NULL,
         *strwin = NULL,
-        *strview =NULL;
+        *strsocket = NULL,
+        *addedstring = NULL,
+        *straddedstring = NULL,
+        *strview = NULL;
     gint i;
     Window  id_xwindow;
-    fprintf(stderr,"init_scene_External1\n");
     if (!desktop_plugin->priv->visible)
         return;
     
-    fprintf(stderr,"init_scene_External2\n");
     exec_path = g_strdup(g_hash_table_lookup(desktop_plugin->priv->hash_theme, "exec_path"));
     window_id = g_strdup(g_hash_table_lookup(desktop_plugin->priv->hash_theme, "window_id"));
     view = g_strdup(g_hash_table_lookup(desktop_plugin->priv->hash_theme, "view"));
     window_name = g_strdup(g_hash_table_lookup(desktop_plugin->priv->hash_theme, "window_name"));
+    gtk_socket_id =  g_strdup(g_hash_table_lookup(desktop_plugin->priv->hash_theme, "gtk_socket_id"));
+    addedstring =  g_strdup(g_hash_table_lookup(desktop_plugin->priv->hash_theme, "added_string"));
     if (!exec_path) 
         return;
     if (window_id){
         strwin = g_strdup_printf(" %s %i", window_id, (gint)GDK_WINDOW_XID(desktop_plugin->priv->window->window));
     }else
         strwin = "";
+    if (gtk_socket_id){
+        strsocket = g_strdup_printf(" %s %i", gtk_socket_id, (int)gtk_socket_get_id (GTK_SOCKET (desktop_plugin->priv->video_socket)));
+    }else
+        strsocket = "";
 
     if (view){
         strview = g_strdup_printf(" %s %i", view, desktop_plugin->priv->view);
     }else
         strview = "";
 
-    run_string = g_strdup_printf("%s%s%s", exec_path, strwin, strview);
+    if (addedstring){
+        straddedstring = g_strdup_printf(" %s", addedstring);
+    }else
+        straddedstring = "";
+
+    run_string = g_strdup_printf("%s%s%s%s%s", exec_path, strwin, strview, strsocket, straddedstring);
     fprintf(stderr, "runs string = %s\n", run_string);
     parsestring(run_string, child_argv);
 
@@ -272,7 +285,7 @@ init_scene_External(AWallpaperPlugin *desktop_plugin){
             id_xwindow = Window_With_Name(GDK_WINDOW_XDISPLAY (desktop_plugin->priv->window->window), 
                 RootWindow( GDK_WINDOW_XDISPLAY (desktop_plugin->priv->window->window), XDefaultScreen( GDK_WINDOW_XDISPLAY (desktop_plugin->priv->window->window))),
                 window_name);
-            //fprintf(stderr,"name %s %i %i\n", window_name, id_xwindow, i);
+            fprintf(stderr,"name %s %i %i\n", window_name, id_xwindow, i);
             if (id_xwindow>0){
                 if (desktop_plugin->priv->one_in_all_view)
                     set_live_bg (GDK_WINDOW_XDISPLAY (desktop_plugin->priv->window->window), 
