@@ -6,8 +6,8 @@
  *       for the code
  * 
  * This software is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public License
- * as published by the Free Software Foundation; either version 2.1 of
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2 of
  * the License, or (at your option) any later version.
  * 
  * This software is distributed in the hope that it will be useful, but
@@ -32,7 +32,7 @@
 #include "livewp-rules.h"
 #include <glib-object.h>
 #include <unistd.h>
-
+#include <X11/Xlib.h>
 
 void fill_priv(Animation_WallpaperPrivate *priv);
 void destroy_scene(AWallpaperPlugin *desktop_plugin);
@@ -47,5 +47,6 @@ void init_scene_Video(AWallpaperPlugin *desktop_plugin);
 void init_scene_External(AWallpaperPlugin *desktop_plugin);
 void init_scene_theme(AWallpaperPlugin *desktop_plugin);
 void create_hildon_actor_text(Actor *actor, AWallpaperPlugin *desktop_plugin); 
-
+void set_live_bg (Display *display, Window xwindow, int mode);
+void create_xwindow (Animation_WallpaperPrivate *priv);
 #endif
